@@ -2,12 +2,12 @@
 hook into AA
 """
 
-from sovtimer import urls, __title__
-
 from django.utils.translation import ugettext_lazy as _
 
-from allianceauth.services.hooks import MenuItemHook, UrlHook
 from allianceauth import hooks
+from allianceauth.services.hooks import MenuItemHook, UrlHook
+
+from sovtimer import __title__, urls
 
 
 class AaSovtimerMenuItem(MenuItemHook):  # pylint: disable=too-few-public-methods
